@@ -1,6 +1,12 @@
+DEV = False
 import typer
 import os
-from .db import delete, draw,fetch,drop,update_data,insert_data
+
+
+if not DEV:
+    from .db import delete, draw,fetch,drop,update_data,insert_data,change_db
+else:
+    from db import delete, draw,fetch,drop,update_data,insert_data,change_db
 
 
 
@@ -12,6 +18,9 @@ print("-"*20,"\n")
 app = typer.Typer()
 
 
+@app.command()
+def config(db):
+    change_db(db)
 
 @app.command()
 def dropall():
